@@ -306,6 +306,62 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetEidResult(self, request):
+        """完成验证后，用EidToken调用本接口获取结果信息，EidToken生成后三天内（3\*24\*3,600秒）可多次拉取。
+
+        :param request: Request instance for GetEidResult.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.GetEidResultRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.GetEidResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetEidResult", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetEidResultResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def GetEidToken(self, request):
+        """每次调用人脸核身小程序服务前，需先调用本接口获取EidToken，用来串联核身流程，在验证完成后，用于获取验证结果信息。
+
+        :param request: Request instance for GetEidToken.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.GetEidTokenRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.GetEidTokenResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetEidToken", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetEidTokenResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetFaceIdResult(self, request):
         """完成验证后，用FaceIdToken调用本接口获取结果信息，FaceIdToken生成后三天内（3\*24\*3,600秒）可多次拉取。
 
